@@ -3,7 +3,7 @@
 
   Copyright (c) 1996 Roland Wunderling, Malte Zoeckler
   Copyright (c) 1998 Michael Meeks
-  Copyright (c) 1998-2000 Dragos Acostachioaie
+  Copyright (c) 1998-2001 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -71,6 +71,7 @@ void help()
     printf(_("  -V  --version          output version information and exit\n"));
     printf(_("  -y  --scan-includes    scan `#include'ed header files\n"));
     printf(_("  -Y  --idl              parse IDL instead of C/C++\n"));
+    printf(_("  -z  --php              parse PHP instead of C/C++\n"));
     printf(_("  -Z  --docbook          generate DocBook SGML instead of HTML\n\n"));
 
     printf(_("Additional options for HTML output:\n"));
@@ -168,6 +169,7 @@ int main(int argc, char **argv)
         { "version", no_argument, 0, 'V' },
 	{ "scan-includes", no_argument, 0, 'y' },
 	{ "idl", no_argument, 0, 'Y' },
+        { "php", no_argument, 0, 'z' },
 	{ "docbook", no_argument, 0, 'Z' },
 
         // additional options for HTML output
@@ -298,6 +300,10 @@ int main(int argc, char **argv)
 		withPrivate = true;	// IDL provides no access control
 		language = LANG_IDL;
 		break;
+	    case 'z':
+		php = true;
+		language = LANG_PHP;
+		break;
 	    case 'Z':
 		doDOCBOOK = true;
 		break;
@@ -531,6 +537,8 @@ int main(int argc, char **argv)
 		language = LANG_JAVA;
 	    if(idl)
 		language = LANG_IDL;
+	    if(php)
+		language = LANG_PHP;
 	    }
 	}
 
@@ -604,7 +612,10 @@ int main(int argc, char **argv)
     if(language == LANG_JAVA)
 	parseJava(root);
     else
-	parseCpp(root);
+	if(language == LANG_PHP)
+	    parsePHP(root);
+	else
+	    parseCpp(root);
 
     checkPackages(root);
     setupLanguageHash();
